@@ -17,7 +17,7 @@ class convert_for_training:
     return nm
 
 
-class Gru2(nn.module):
+class Gru2(nn.Module):
 
   def forward(self, x, 
                 init_states):
